#!/bin/sh
set -ev

# Volumes
POSTGRES_DATA="${VOLUMES_DIR}/sambro/postgres_data"
SAHANA_DATA="${VOLUMES_DIR}/sambro/sahana_data"
SAHANA_CONF="${VOLUMES_DIR}/sambro/sahana_conf"
SAHANA_LAYER="${LAYERS_DIR}/sahana_0.0.1-200403"

# Create Postgres instance
install -o 105432 -g 105432 -m 700 -d ${POSTGRES_DATA}
spoc-container exec sambro-postgres -- initdb -D /var/lib/postgresql

# Configure Postgres
install -o 105432 -g 105432 -m 600 postgres_data/postgresql.conf ${POSTGRES_DATA}/postgresql.conf
install -o 105432 -g 105432 -m 600 postgres_data/pg_hba.conf ${POSTGRES_DATA}/pg_hba.conf

# Create PostgreSQL user and database
export SAMBRO_PWD=$(head -c 18 /dev/urandom | base64 | tr -d '+/=')
spoc-container start sambro-postgres
envsubst <createdb.sql | spoc-container exec sambro-postgres -- psql

# Prepare persistent directory structure
install -o 108080 -g 108080 -m 750 -d ${SAHANA_DATA}/databases
install -o 108080 -g 108080 -m 750 -d ${SAHANA_DATA}/uploads
cp -rp ${SAHANA_LAYER}/srv/web2py/applications/eden/models ${SAHANA_CONF}
cp -rp ${SAHANA_LAYER}/srv/web2py/applications/eden/modules/templates/SAMBRO ${SAHANA_DATA}/SAMBRO

# Configure SAMBRO
export SAMBRO_HMAC=$(head -c 18 /dev/urandom | base64 | tr -d '+/=')
export SAMBRO_ADMIN_USER="admin@example.com"
export SAMBRO_ADMIN_PWD=$(head -c 12 /dev/urandom | base64 | tr -d '+/=')
envsubst <sahana_conf/000_config.py | install -o 108080 -g 108080 -m 640 /dev/stdin ${SAHANA_CONF}/000_config.py
envsubst <sahana_data/masterUsers.csv | install -o 108080 -g 108080 -m 640 /dev/stdin ${SAHANA_DATA}/masterUsers.csv
install -o 108080 -g 108080 -m 640 sahana_conf/00_settings.py ${SAHANA_CONF}/00_settings.py
install -o 108080 -g 108080 -m 640 sahana_data/SAMBRO/config.py ${SAHANA_DATA}/SAMBRO/config.py

# Populate database
spoc-container exec -u sahana sambro -- sh -c 'cd /srv/web2py; ./web2py.py -S eden -M -R applications/eden/static/scripts/tools/noop.py'

# Set "production values" (increases performance) only if the DEBUG environment variable is not set
if [ ${DEBUG:-0} -eq 0 ]; then
    sed -i 's/settings.base.migrate = True/settings.base.migrate = False/' ${SAHANA_CONF}/000_config.py
    sed -i 's/settings.base.debug = True/settings.base.debug = False/' ${SAHANA_CONF}/000_config.py
    sed -i 's/#settings.base.prepopulate = 0/settings.base.prepopulate = 0/' ${SAHANA_CONF}/000_config.py
fi

# Stop services required for setup
spoc-container stop sambro-postgres

# Register application
vmmgr register-app sambro sambro "${SAMBRO_ADMIN_USER}" "${SAMBRO_ADMIN_PWD}"
